==> cvsnt-2.5.03.2704.tar.gz: cvsnt-2.5.03.2704/cvsntcpl/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by cvsntcpl.rc
//
#define IDS_NAME                        1
#define IDS_DESCRIPTION                 2
#define IDS_STRING3                     3
#define IDD_PAGE1                       106
#define IDC_START                       1000
#define IDC_STOP                        1001
#define IDC_STATUS                      1002
#define IDC_VERSION                     1003
#define IDD_NEWROOT                     1004
#define IDC_STATUS2                     1005
#define IDD_PAGE2                       1007
#define IDC_START2                      1008
#define IDI_ICON1                       1009
#define IDD_PAGE3                       1010
#define IDC_STOP2                       1011
#define IDD_PAGE5                       1015
#define IDD_PAGE6                       1016
#define IDC_ADDROOT                     1019
#define IDC_DELETEROOT                  1020
#define IDC_ROOTLIST                    1021
#define IDC_EDITROOT                    1022
#define IDC_NOREVERSEDNS                1023
#define IDC_ROOT                        1024
#define IDC_LOCKSERVERLOCAL             1025
#define IDC_SELECT                      1026
#define IDC_LOCKSERVER                  1027
#define IDC_NAME                        1028
#define IDB_BITMAP1                     1029
#define IDC_DESCRIPTION                 1030
#define IDC_ALLOWTRACE                  1031
#define IDC_CASESENSITIVE               1032
#define IDC_UNICODESERVER               1033
#define IDD_MAINFRAME                   1034
#define IDC_READONLY                    1035
#define IDC_REMOTEINIT                  1036
#define IDD_PAGE7                       1037
#define IDC_ENABLEZEROCONF              1038
#define IDC_ATOMICCHECKOUTS             1039
#define IDC_EDIT1                       2002
#define IDC_CHANGETEMP                  2003
#define IDC_PSERVERPORT                 2004
#define IDC_LOCKSERVERPORT              2005
#define IDC_PRIVATEKEY                  2006
#define IDC_SPIN1                       2007
#define IDC_SPIN2                       2008
#define IDC_ENCRYPTION                  2009
#define IDC_DEFAULTDOMAIN               2010
#define IDC_COMPRESSION                 2011
#define IDC_SSLCERT                     2012
#define IDC_RUNASUSER                   2013
#define IDC_COPYING                     2014
#define IDC_LOGO                        2015
#define IDC_LEGACY                      2016
#define IDC_CVSNT                       2017
#define IDC_PUBLISH                     2018
#define IDC_OLDVERSION_NONCVSNT         2019
#define IDC_SERVERNAME                  2020
#define IDC_DEFAULT                     2021
#define IDC_OLDCHECKOUT_NONCVSNT        2022
#define IDC_ALLOWEDCLIENTS              2023
#define IDC_ANONUSER                    2024
#define IDC_HIDESTATUS_NONCVSNT         2025
#define IDC_SMTPINTERNAL                2026
#define IDC_HIDESTATUS_NONCVSNT2        2027
#define IDC_IGNOREWRAPPERS_NONCVSNT     2028
#define IDC_SMTPEXTERNAL                2029
#define IDC_OLDVERSION_CVSNT            2030
#define IDC_OLDCHECKOUT_CVSNT           2031
#define IDC_HIDESTATUS_CVSNT            2032
#define IDC_OLDCHECKOUT_OLDCVSNT        2033
#define IDC_IGNOREWRAPPERS_CVSNT        2034
#define IDC_SMTPSERVERNAME              2035
#define IDC_LIST1                       2036
#define IDC_BUTTON1                     2037
#define IDC_ZEROCONF                    2038
#define IDC_CHECK1                      2039
#define IDC_REPLICATION                 2039
#define IDC_ONLINE                      2040
#define IDC_REPLICATIONPORT             2040
#define IDC_REPLICATIONPORT_TEXT        2041
#define IDC_BIGMEM                      2042
#define IDC_BUGNUMS                     2043
#define IDC_BUGMSG                      2044
#define IDC_BUGSYNONYM                  2045

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        1038
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         2046
#define _APS_NEXT_SYMED_VALUE           1000
#endif
#endif

==> cvsnt-2.5.04.3236.tar.gz: cvsnt-2.5.04.3236/cvsntcpl/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by cvsntcpl.rc
//
#define IDS_NAME                        1
#define IDS_DESCRIPTION                 2
#define IDS_STRING3                     3
#define IDD_PAGE1                       106
#define IDC_START                       1000
#define IDC_STOP                        1001
#define IDC_STATUS                      1002
#define IDC_VERSION                     1003
#define IDD_NEWROOT                     1004
#define IDC_STATUS2                     1005
#define IDD_PAGE2                       1007
#define IDC_START2                      1008
#define IDI_ICON1                       1009
#define IDD_PAGE3                       1010
#define IDC_STOP2                       1011
#define IDD_PAGE5                       1015
#define IDD_PAGE6                       1016
#define IDC_ADDROOT                     1019
#define IDC_DELETEROOT                  1020
#define IDC_ROOTLIST                    1021
#define IDC_EDITROOT                    1022
#define IDC_NOREVERSEDNS                1023
#define IDC_ROOT                        1024
#define IDC_LOCKSERVERLOCAL             1025
#define IDC_SELECT                      1026
#define IDC_LOCKSERVER                  1027
#define IDC_NAME                        1028
#define IDB_BITMAP1                     1029
#define IDC_DESCRIPTION                 1030
#define IDC_ALLOWTRACE                  1031
#define IDC_CASESENSITIVE               1032
#define IDC_UNICODESERVER               1033
#define IDD_MAINFRAME                   1034
#define IDC_READONLY                    1035
#define IDC_REMOTEINIT                  1036
#define IDD_PAGE7                       1037
#define IDC_ENABLEZEROCONF              1038
#define IDD_PAGE4                       1038
#define IDC_ATOMICCHECKOUTS             1039
#define IDD_DIALOG1                     1040
#define IDC_GLOBALSCRIPT                1041
#define IDC_EDIT1                       2002
#define IDC_CHANGETEMP                  2003
#define IDC_REPOSITORY                  2003
#define IDC_PSERVERPORT                 2004
#define IDC_EDIT3                       2004
#define IDC_PASSPHRASE                  2004
#define IDC_LOCKSERVERPORT              2005
#define IDC_PRIVATEKEY                  2006
#define IDC_SPIN1                       2007
#define IDC_SPIN2                       2008
#define IDC_ENCRYPTION                  2009
#define IDC_DEFAULTDOMAIN               2010
#define IDC_COMPRESSION                 2011
#define IDC_SSLCERT                     2012
#define IDC_RUNASUSER                   2013
#define IDC_COPYING                     2014
#define IDC_LOGO                        2015
#define IDC_LEGACY                      2016
#define IDC_CVSNT                       2017
#define IDC_PUBLISH                     2018
#define IDC_OLDVERSION_NONCVSNT         2019
#define IDC_SERVERNAME                  2020
#define IDC_DEFAULT                     2021
#define IDC_OLDCHECKOUT_NONCVSNT        2022
#define IDC_ALLOWEDCLIENTS              2023
#define IDC_ANONUSER                    2024
#define IDC_HIDESTATUS_NONCVSNT         2025
#define IDC_SMTPINTERNAL                2026
#define IDC_HIDESTATUS_NONCVSNT2        2027
#define IDC_IGNOREWRAPPERS_NONCVSNT     2028
#define IDC_SMTPEXTERNAL                2029
#define IDC_OLDVERSION_CVSNT            2030
#define IDC_OLDCHECKOUT_CVSNT           2031
#define IDC_HIDESTATUS_CVSNT            2032
#define IDC_OLDCHECKOUT_OLDCVSNT        2033
#define IDC_IGNOREWRAPPERS_CVSNT        2034
#define IDC_SMTPSERVERNAME              2035
#define IDC_LIST1                       2036
#define IDC_BUTTON1                     2037
#define IDC_ZEROCONF                    2038
#define IDC_CHECK1                      2039
#define IDC_REPLICATION                 2039
#define IDC_READWRITE                   2039
#define IDC_ONLINE                      2040
#define IDC_REPLICATIONPORT             2040
#define IDC_REPLICATIONPORT_TEXT        2041
#define IDC_TYPE                        2042
#define IDC_SERVER                      2043
#define IDC_REMOTEGROUP                 2044
#define IDC_SERVERTEXT                  2045
#define IDC_REPOSITORYTEXT              2046
#define IDC_PASSPHRASETEXT              2047
#define IDC_CVSNTVERSION                2048
#define IDC_REGISTRATION                2049
#define IDC_HOSTOS                      2050
#define IDC_UPTIME                      2051
#define IDC_USERS                       2052
#define IDC_SIMULTANEOUSUSERS           2053
#define IDC_TIMEPERUSER                 2054
#define IDC_SESSIONCOUNT                2055
#define IDC_MESSAGE                     2056

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        1042
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         2057
#define _APS_NEXT_SYMED_VALUE           1000
#endif
#endif
